// Copyright (c) 2010, SoftLayer Technologies, Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright notice,
//    this list of conditions and the following disclaimer.
//  * Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.
//  * Neither SoftLayer Technologies, Inc. nor the names of its contributors may
//    be used to endorse or promote products derived from this software without
//    specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//

/*
    RefreshButton
    
    A class that creates a button similar to Apple's "info" button
    with a label that displays the "refresh" icon.  
    
    This class uses CSS animations to handle the button fades
    and such where Apple's info button uses JavaScript-based animators
    (probably for backward compatibility reasons).
*/
function RefreshButton (buttonDiv)
{
    this.buttonDiv = buttonDiv
    this.showing = false;
    
    // Utility routine that creates and styles an image element
    // for the refresh "label"
    this.createImage = function()
    {
        var imageElement = document.createElement("img");
        imageElement.setAttribute("src", "Images/Refresh.png");

        imageElement.style.position = "absolute";
        imageElement.style.width = "100%";
        imageElement.style.height = "100%";
        imageElement.style.left = "0px"
        imageElement.style.top = "0px";

        return imageElement;
    }
    
    // Utility routine that creates a canvas element (containing
    // a black circle) that is used as the background for the
    // refresh button.
    this.createCanvas = function ()
    {
        var circleCanvas = document.createElement("canvas");

        var width = this.buttonDiv.clientWidth + 4;
        var height = this.buttonDiv.clientHeight + 4;
        
        circleCanvas.width = width;
        circleCanvas.height = height;
        
        circleCanvas.style.position = "absolute"
        circleCanvas.style.left = "-2px"
        circleCanvas.style.top = "-2px"
        circleCanvas.style.opacity = 0;

        var cgContext = circleCanvas.getContext('2d')
        cgContext.beginPath()
        cgContext.arc(width/2.0, height/2.0, height/2.0, 0, 360)
        cgContext.fillStyle = "black"
        cgContext.fill();
        
        return circleCanvas;
    }
    
    var self = this;
    
    // Fade in the entire button element.
    this.showRefreshButton = function ()
    {
        if(!self.showing)
        {
            self.buttonDiv.style.opacity = 1.0;
            self.showing = true;
        }
    }
    
    // Fade out the entire button element.
    this.hideRefreshButton = function ()
    {
        if(self.showing)
        {
            self.buttonDiv.style.opacity = 0;
            self.showing = false;
        }
    }

    // Fade in the circular background of the button
    this.showCircleBackground = function ()
    {
        self.circleBackground.style.opacity = 0.25;
    }

    // Fade out the circular background of the button
    this.hideCircleBackground = function ()
    {
        self.circleBackground.style.opacity = 0;
    }
    
    // Finish initialization by putting all the pieces together.
    var refreshImage = this.createImage()
    this.circleBackground = this.createCanvas();


    // The hard-coded 0.25s was chosen to match the Apple info button's behavior.
    this.buttonDiv.style.webkitTransition = "opacity 0.25s";
    this.buttonDiv.appendChild(this.circleBackground)
    this.buttonDiv.appendChild(refreshImage)
    this.buttonDiv.addEventListener("mouseover", this.showCircleBackground)
    this.buttonDiv.addEventListener("mouseout", this.hideCircleBackground)

    // Watch for mouse moved on the front element and use them to
    // hide/show the button.
    var front = document.getElementById("front");
    front.addEventListener("mousemove", this.showRefreshButton);
    front.addEventListener("mouseout", this.hideRefreshButton);
}