// Copyright (c) 2010, SoftLayer Technologies, Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright notice,
//    this list of conditions and the following disclaimer.
//  * Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.
//  * Neither SoftLayer Technologies, Inc. nor the names of its contributors may
//    be used to endorse or promote products derived from this software without
//    specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//

/*
    TicketsWidgetBackController
    
    A controller managing the controls on the back side of the widget.
*/

TicketsWidgetBackController = Class.create(DC.Controller, {
    load : function ()
    {
        this.usernameEntry = document.getElementById("username_entry")
        this.apiKeyEntry = document.getElementById("api_key_entry")

        /* Bind the username entry to the current user of the widget */
        this.usernameEntry.object.bindNameToKeyPath("value", "*.currentUser.username", softlayer.ticketsWidget)

        /* Similarly, bind the apiKey entry field to the current user of the widget */
        this.apiKeyEntry.object.bindNameToKeyPath("value", "*.currentUser.apiKey", softlayer.ticketsWidget)

        /* Set the initial values of the fields */
        this.usernameEntry.value = softlayer.ticketsWidget.valueForKeyPath("currentUser.username")
        this.apiKeyEntry.value = softlayer.ticketsWidget.valueForKeyPath("currentUser.apiKey")

        var doneButton = document.getElementById("done")
        if(doneButton)
        {
            doneButton.onclick = function (event) { softlayer.ticketsWidget.flipToFront(); }
        }
        
        var validateButton = document.getElementById("validate_button")
        if(validateButton)
        {
            var self = this;
            validateButton.onclick = function (event) { self.validateUserCredentials(); }
        }
    },

    show : function ()
    {
        if(!softlayer.ticketsWidget.currentUser.hasBeenValidated)
        {
            this.setStatusText("");
            this.validateUserCredentials();
        } else {
            this.setStatusText("The acccount settings are valid");
        }
    },

    hide : function ()
    {
    },

    validateUserCredentials: function ()
    {
        username = this.usernameEntry.value;
        api_key = this.apiKeyEntry.value;
        
        if(username.length > 0 && api_key.length > 0)
        {
            var self = this;
            
            this.setStatusText("");

            softlayer.ticketsWidget.progressHUD.beginActivityWithContextAndTitle("validatingUserContext", "Validating User Credentials…")

            // Ask the account user to validate itself.  If the user is valid, save it
            // in the prefs as the current user.
            var potentialUser = new SLAccountUser(username, api_key);
            potentialUser.validate(function (userIsValid) {
                softlayer.ticketsWidget.progressHUD.endActivityWithContext("validatingUserContext");

                if(userIsValid)
                {
                    softlayer.ticketsWidget.currentUser = potentialUser;
                    softlayer.ticketsWidget.currentUser.saveInPreferences();

                    self.setStatusText("The acccount settings are valid");
                } else {
                    self.setStatusText("The acccount settings are not valid");
                }
            });
        }
    },
    
    setStatusText: function (newText)
    {
        document.getElementById("validation_status").innerText = newText;
    }
});
