// Copyright (c) 2010, SoftLayer Technologies, Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright notice,
//    this list of conditions and the following disclaimer.
//  * Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.
//  * Neither SoftLayer Technologies, Inc. nor the names of its contributors may
//    be used to endorse or promote products derived from this software without
//    specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//


// We create a separate namespace for our own global variables.
var softlayer = {
    API_BASE_URL : "https://api.service.softlayer.com/rest/v3",
}

//
// Function: load()
// Called by HTML body element's onload event 
// when the widget is ready to start
//
function load()
{
    dashcode.setupParts()
    
    // Create the tickets widget controller and store a reference to it
    // in the window.  Pass the load message on to that controller.
    softlayer.ticketsWidget = new TicketsWidget()
    softlayer.ticketsWidget.load()
}

//
// Function: remove()
// Called when the widget has been removed from the Dashboard
//
function remove()
{
    // Pass the message on to the widget controller
    if(softlayer.ticketsWidget)
    {
        softlayer.ticketsWidget.remove()
    }
}

//
// Function: hide()
// Called when the widget has been hidden
//
function hide()
{
    // Pass the message on to the widget controller
    if(softlayer.ticketsWidget)
    {
        softlayer.ticketsWidget.hide();
    }
}

//
// Function: show()
// Called when the widget has been shown
//
function show()
{
    // Pass the message on to the widget controller
    if(softlayer.ticketsWidget)
    {
        softlayer.ticketsWidget.show();
    }
}

//
// Function: sync()
// Called when the widget has been synchronized with .Mac
//
function sync()
{
    // This space intentionally left (almost) blank.
}

//
// Function: showBack(event)
// Called when the info button is clicked to show the back of the widget
//
// event: onClick event from the info button
//
function showBack(event)
{
    // Pass the message on to the widget controller
    if(softlayer.ticketsWidget)
    {
        softlayer.ticketsWidget.flipToBack();
    }
}

//
// Function: showFront(event)
// Called when the done button is clicked from the back of the widget
//
// event: onClick event from the done button
//
function showFront(event)
{
    // Pass the message on to the widget controller
    if(softlayer.ticketsWidget)
    {
        softlayer.ticketsWidget.flipToFront();
    }
}

/* finish widget setup */
if (window.widget) 
{
    widget.onremove = remove
    widget.onhide = hide
    widget.onshow = show
    widget.onsync = sync
}